@@ -10,7 +10,11 @@
 # This module is optional and not required for use with the Notecard.
 
 import notecard
-from .validators import validate_card_object
+import sys
+if sys.implementation.name == 'micropython':
+    from validators import validate_card_object
+else:
+    from .validators import validate_card_object
 
 
 @validate_card_object
